@@ -5,8 +5,16 @@
 Utilities for working with dates and times.
 
 .. extras-require:: dates
+	:pyproject:
 
-	pytz >=2019.1
+
+**Data:**
+
+.. autosummary::
+
+	~domdf_python_tools.dates.months
+	~domdf_python_tools.dates.month_full_names
+	~domdf_python_tools.dates.month_short_names
 
 """
 #
@@ -19,20 +27,23 @@ Utilities for working with dates and times.
 #  Copyright © 1995-2000 Corporation for National Research Initiatives. All rights reserved.
 #  Copyright © 1991-1995 Stichting Mathematisch Centrum. All rights reserved.
 #
-#  This program is free software; you can redistribute it and/or modify
-#  it under the terms of the GNU Lesser General Public License as published by
-#  the Free Software Foundation; either version 3 of the License, or
-#  (at your option) any later version.
+#  Permission is hereby granted, free of charge, to any person obtaining a copy
+#  of this software and associated documentation files (the "Software"), to deal
+#  in the Software without restriction, including without limitation the rights
+#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+#  copies of the Software, and to permit persons to whom the Software is
+#  furnished to do so, subject to the following conditions:
 #
-#  This program is distributed in the hope that it will be useful,
-#  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-#  GNU Lesser General Public License for more details.
+#  The above copyright notice and this permission notice shall be included in all
+#  copies or substantial portions of the Software.
 #
-#  You should have received a copy of the GNU Lesser General Public License
-#  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-#  MA 02110-1301, USA.
+#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+#  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+#  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+#  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+#  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
+#  OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE
+#  OR OTHER DEALINGS IN THE SOFTWARE.
 #
 #  calc_easter from https://code.activestate.com/recipes/576517-calculate-easter-western-given-a-year/
 #  Copyright © 2008 Martin Diers
@@ -108,10 +119,10 @@ def utc_timestamp_to_datetime(
 	"""
 	Convert UTC timestamp (seconds from UNIX epoch) to a :class:`datetime.datetime` object.
 
-	If ``output_tz`` is None the timestamp is converted to the platform’s local date and time,
+	If ``output_tz`` is :py:obj:`None` the timestamp is converted to the platform’s local date and time,
 	and the local timezone is inferred and set for the object.
 
-	If ``output_tz`` is not None, it must be an instance of a :class:`datetime.tzinfo` subclass,
+	If ``output_tz`` is not :py:obj:`None`, it must be an instance of a :class:`datetime.tzinfo` subclass,
 	and the timestamp is converted to ``output_tz``’s time zone.
 
 
@@ -222,6 +233,8 @@ def check_date(month: Union[str, int], day: int, leap_year: bool = True) -> bool
 		This function will return :py:obj:`True` for the 29th Feb.
 		If you don't want this behaviour set ``leap_year`` to :py:obj:`False`.
 
+	.. latex:vspace:: -10px
+
 	:param month: The month to test.
 	:param day: The day number to test.
 	:param leap_year: Whether to return :py:obj:`True` for 29th Feb.
@@ -288,8 +301,11 @@ def get_utc_offset(
 def get_timezone(tz: str, date: Optional[datetime.datetime] = None) -> Optional[datetime.tzinfo]:
 	"""
 	Returns a localized ``pytz.timezone`` object for the given date.
+
 	If ``date`` is :py:obj:`None` then the current date is used.
 
+	.. latex:vspace:: -10px
+
 	:param tz: A string representing a pytz timezone
 	:param date: The date to obtain the timezone for
 	"""
